#!/bin/bash
###########################################################################
# Eole NG - 2007
# Copyright Pole de Competence Eole  (Ministere Education - Academie Dijon)
# Licence CeCill  cf /root/LicenceEole.txt
# eole@ac-dijon.fr
#
# sauvegarde.sh
#
# script de création d'archives de sauvegarde zephir
#
###########################################################################

Lock="sauvegarde"
Excl="maj"

. /usr/share/eole/FonctionsEoleNg
. ParseDico

day=`date +%d-%m-%Y`
backup_dir=/var/lib/zephir_backups
tmp_backup=$backup_dir/$day
pg_data=/var/lib/postgresql/8.3/main
pg_dir=/etc/postgresql/8.3/main
pg_perms=$pg_dir/pg_hba.conf
pg_service=postgresql-8.3

if [ ! -d $backup_dir ]
then
	mkdir $backup_dir
fi
rm -rf $tmp_backup
mkdir $tmp_backup

# on arrête temporairement le backend zephir (cohérence des données)
service zephir stop &> /dev/null

# postgres : se mettre en mode sans mot de passe
mv -f $pg_perms $pg_perms.savezephir
echo -e -e "local\tall\tall\ttrust" > $pg_perms
chown postgres.postgres $pg_perms
chmod 600 $pg_perms
service $pg_service reload &> /dev/null

# sauvegarde des données de la base postgresql
echo -e
EchoCyan "Sauvegarde en cours, patientez ..."

echo -e " - base postgresql"
su - postgres -c "pg_dumpall > /tmp/backup_db.sql"
mv /tmp/backup_db.sql $tmp_backup/backup_db.sql

# postgres : se remettre en mode mot de passe
rm -f $pg_perms
mv -f $pg_perms.savezephir $pg_perms
chown postgres.postgres $pg_perms
chmod 600 $pg_perms
service $pg_service reload &> /dev/null

# sauvegarde des répertoires et fichiers importants

pushd /var/lib > /dev/null 2>&1

echo -e " - base ldap"
# sauvegarde de la base ldap
# tar -cpf $tmp_backup/var_lib_ldap.tar ldap
slapcat -l $tmp_backup/ldap.ldif

echo -e " - configuration des serveurs"
# /var/lib/zephir
tar -cpf $tmp_backup/var_lib_zephir.tar zephir

# /etc/uucp/
cd /etc
tar -cpf $tmp_backup/etc_uucp.tar uucp
echo -e " - clés de connexion"
# /var/spool/uucp/
cd /var/spool
tar -cpf $tmp_backup/var_spool_uucp.tar uucp

# on relance le service
service zephir start &> /dev/null

echo -e " - configuration eole"
mkdir -p $tmp_backup/etc_eole/dicos
cp -rf /etc/eole/dicos/local $tmp_backup/etc_eole/dicos/
cp -rf /etc/eole/dicos/variante $tmp_backup/etc_eole/dicos/
cp -rf /etc/eole/patch $tmp_backup/etc_eole/
cp /etc/eole/config.eol $tmp_backup/etc_eole/
cd $tmp_backup/etc_eole/
tar -cpf $tmp_backup/etc_eole.tar config.eol dicos patch
cd ..
rm -rf etc_eole

# création du fichier de sauvegarde compressé
EchoCyan "Compression de l'archive..."
cd $backup_dir
tar -czf $day.tar.gz $day
echo -e
EchoVert "Archive créée : $backup_dir/$day.tar.gz"
echo -e

# suppression du répertoire temporaire
rm -rf $tmp_backup
# retour au répertoire d'origine
popd >/dev/null 2>&1
