#!/bin/bash
###########################################################################
# Eole NG - 2007
# Copyright Pole de Competence Eole  (Ministere Education - Academie Dijon)
# Licence CeCill  cf /root/LicenceEole.txt
# eole@ac-dijon.fr
#
# zephir.sh
#
# script d'instanciation du module Zephir NG
#
###########################################################################

# Appel Bibliothèque
. ParseDico

export PYTHONPATH=/usr/share/:$PYTHONPATH
pg_data=/var/lib/postgresql/8.3/main
pg_dir=/etc/postgresql/8.3/main
pg_perms=$pg_dir/pg_hba.conf
pg_service=/etc/init.d/postgresql-8.3

# 1. se mettre en mode sans mot de passe

$pg_service stop >/dev/null
mv $pg_perms $pg_perms.savezephir
echo -e "local\tall\tall\ttrust" > $pg_perms
chown postgres.postgres $pg_perms
chmod 600 $pg_perms
$pg_service start >/dev/null

# 2. changer/créer le mot de passe postgres (exemple eole)

su - postgres -c "psql -d template1 -c \"ALTER USER postgres WITH PASSWORD 'eole'\"" >/dev/null

# 3. créer un utilisateur pour l'application (exemple zephir)

grep -q zephir $pg_data/global/pg_database
if [ $? -eq 0 ]
then
	echo "Créer les utilisateurs et données de base (oui/non)"
	echo "(** Attention toutes les données actuelles seront perdues **) ?";read Reponse
else
	Reponse="oui"
fi

if [ "$Reponse" == "oui" -o "$Reponse" == "o" -o "$Reponse" = "O" ]
then
	# on supprime les anciennes données
	rm -rf /etc/uucp/serveurs/*
	rm -rf /var/lib/zephir/conf/*
	rm -rf /var/lib/zephir/modules/*
	cp /usr/share/zephir/uucp_zephir/passwd_zephir /etc/uucp/
	# créer les bases et les tables au nom de cet utilisateur (exemple à partir du fichier tables.sql)
	su - postgres <<EOF
dropdb zephir &>/dev/null
psql -c "SET autocommit TO 'on';CREATE USER \"zephir\" WITH  PASSWORD 'eole' CREATEDB NOCREATEUSER" -d template1 &> /dev/null

createdb zephir -Uzephir &>/dev/null
psql -d zephir -f /usr/share/zephir/sql/zephir.sql -Uzephir &>/dev/null

EOF

fi

## Changement des mots de passe pour ldap et postgres (generation automatique)
/usr/share/eole/gen_pwd.py >/dev/null

# 4. se remettre en mode mot de passe

rm -f $pg_perms
mv -f $pg_perms.savezephir $pg_perms
chown postgres.postgres $pg_perms
$pg_service stop &> /dev/null
$pg_service start

# 5. initialisation des données zephir de base si demandé
# demarrage des services ldap et zephir (mode minimum)

/etc/init.d/networking restart >/dev/null
/etc/init.d/slapd restart >/dev/null
/etc/init.d/zephir restart noscan >/dev/null



if [ "$Reponse" == "oui" -o "$Reponse" == "o" -o "$Reponse" = "O" ]
then
	# si le serveur ldap est local, initialisation des utilisateurs de base
	if [ "$serveur_ldap" == "127.0.0.1" -o "$serveur_ldap" == "localhost" ]
	then
		# saisie du mot de passe de l'administrateur de base zephir (dans ldap)
		stty -echo
		read -p "Mot de passe de l'administrateur de base ($admin_zephir) : " pass_zeph
		echo
		read -p "Confirmation du mot de passe                            : " pass_zeph2
		echo
		while [ "$pass_zeph" != "$pass_zeph2" ]
		do
			read -p "Mot de passe de l'administrateur de base ($admin_zephir) : " pass_zeph
			echo
			read -p "Confirmation du mot de passe                            : " pass_zeph2
			echo
		done
		stty echo
		echo "Création des utilisateurs dans l'annuaire ..."
		/etc/init.d/slapd stop >/dev/null
		[ -d /var/lib/ldap ] || mkdir /var/lib/ldap
		rm -f /var/lib/ldap/*.* >/dev/null
		chown -R openldap.openldap /var/lib/ldap
		/etc/init.d/slapd start >/dev/null
		sleep 2
		python /usr/share/zephir/utils/init_ldap.py $pass_zeph
	else
		pass_zeph="toto"
		pass_ok=0
		stty -echo
		while [ $pass_ok -ne 1 ]
		do
			read -p "Mot de passe actuel de $admin_zephir (annuaire distant) ? : " pass_zeph
			[ -z "$pass_zeph" ] && exit 1
			# test de bind ldap
			DN=`ldapsearch -x -h $serveur_ldap -b "$base_ldap" "uid=$admin_zephir" | grep dn | cut -d" " -f2` &>/dev/null
			ldapsearch -x -h $serveur_ldap -b "$base_ldap" -D "$DN" -w "$pass_zeph" "uid=$admin_zephir" &> /dev/null
			if [ $? -eq 0 ]
			then
				pass_ok=1
			else
				echo "Erreur d\'authentification LDAP"
			fi
		done
		stty echo
		echo
	fi
	# insertion des données de base
	echo "Insertion des données minimum dans la base ..."
	cd /usr/share/zephir/utils
	python init_base.py $pass_zeph
	if [ $? -ne 0 ]
	then
		echo "Erreur de mise en place des données de base"
		exit 1
	fi

else
	# cas de changement d'administrateur (ex : passage sur ldap externe)
	# sans écrasement de la base de données.
	python /usr/share/zephir/utils/init_base.py --verify
fi

## 6. Creer le repertoire .ssh pour uucp
if [ ! -d /var/spool/uucp/.ssh ]
then
	mkdir /var/spool/uucp/.ssh
	chown uucp.uucp /var/spool/uucp/.ssh
	chmod 700 /var/spool/uucp/.ssh
fi

# FIXME/Eole-2.2 : plantage sans cette ligne !
$pg_service stop
echo
